==> openeclass-4.0.2.tar.gz: openeclass-4.0.2/lang/it/common.inc.php <==
<?php
/*
 *  ========================================================================
 *  * Open eClass
 *  * E-learning and Course Management System
 *  * ========================================================================
 *  * Copyright 2003-2024, Greek Universities Network - GUnet
 *  *
 *  * Open eClass is an open platform distributed in the hope that it will
 *  * be useful (without any warranty), under the terms of the GNU (General
 *  * Public License) as published by the Free Software Foundation.
 *  * The full license can be read in "/info/license/license_gpl.txt".
 *  *
 *  * Contact address: GUnet Asynchronous eLearning Group
 *  *                  e-mail: info@openeclass.org
 *  * ========================================================================
 *
 */

// Message file for language it
// Generated 2024-01-19 17:14:55

$langCourse = "Corso";
$langEclass = 'Open eClass - Piattaforma di eLearning asincrona';
$langTeacher = "Insegnante";
$langOfTeacher = "dell'Insegnante";
$langTeachers = "Insegnanti";
$langOfTeachers = "degli Insegnanti";
$langsTeacher = "insegnante";
$langsOfTeacher = "dell'insegnante";
$langsTeachers = "insegnanti";
$langsOfTeachers = "degli insegnanti";
$langStudent = "Studente";
$langOfStudent = "dello Studente";
$langStudents = "Studenti";
$langOfStudents = "degli Studenti";
$langsStudent = "studente";
$langsOfStudent = "dello studente";
$langsStudents = "studenti";
$langsOfStudents = "degi studenti";
$langsOfStudentss = "studenti";
$langsstudent_acc = "studente";
$langGuest = 'Utente Ospite';
$langGuests = 'Utenti Ospiti';
$langFaculty = 'Facoltà - Dipartimento';
$langOfFaculty = 'della Facoltà - del Dipartimento';
$langOfFaculties = "delle Facoltà - dei Dipartimenti";
$langFaculties = "Facoltà - Dipartimenti";
$langsFaculty = "facoltà - dipartimento";
$langsFaculties = "facoltà - dipartimenti";
$langpre = "Laurea";
$langpost = "Post Laurea";
$langother = 'Altro';
$langInfoAbout = "La piattaforma <strong>$siteName</strong>  è un sistema completo di gestione di corsi elettronici. Adotta la filosofia del software a codice sorgente aperto e supporta il servizio di e-learning asincrono senza limitazioni ed impegni. L'accesso al servizio si fa con l'uso di un semplice web browser senza l'esigenza di nozioni tecniche e speciali.";
$langExtrasLeft = '';
$langExtrasRight = '';
$langCourses = "Corsi";
$langGroupTutor = "Group Tutor";
$langEditor = "Insegnante di Sostegno";
$langOfEditor = "Tutor Assistant";
$langsEditor = "tutor assistant";
$langsOfEditor = "tutor assistant";
$langsOfGroupTutor = "group tutor";
$langOfCourse = "Course";
$langOfCourses = "Courses";
$langsCourse = "course";
$langsCourses = "courses";
$langsOfCourse = "course";
$langsOfCourses = "courses";
$langsOfFaculty = "category";
$langsOfFaculty = "category";
$langCourseAdmin = "Admin";
$langOfCourseAdmin = "Admin";
$langCourseAdmins = "Admins";
$langOfCourseAdmins = "Admins";
$langsCourseAdmin = "admin";
$langsOfCourseAdmin = "admin";
$langsCourseAdmins = "admins";
$langsOfCourseAdmins = "admins";
$langCourseAdminTeacher = "Admin - Teacher";
$langOfCourseAdminTeacher = "Admin - Teacher";
$langCourseAdminTeachers = "Admins - Teachers";
$langOfCourseAdminTeachers = "Admins - Teachers";
$langsCourseAdminTeacher = "admin - teacher";
$langsOfCourseAdminTeacher = "admin - teacher";
$langsCourseAdminTeachers = "admins - teachers";
$langsOfCourseAdminTeachers = "admins - teachers";
$langCourseReviewer = "Reviewer";
$langOfCourseReviewer = "Reviewer";
$langsCourseReviewer = "reviewer";
$langsOfCourseReviewer = "reviewer";

==> openeclass-4.2.1.tar.gz: openeclass-4.2.1/lang/it/common.inc.php <==
<?php

// Message file for language it
// Generated 2025-12-02 16:31:18

$langCourse = "Corso";
$langEclass = 'Open eClass - Piattaforma di eLearning asincrona';
$langTeacher = "Insegnante";
$langOfTeacher = "dell'Insegnante";
$langTeachers = "Insegnanti";
$langOfTeachers = "degli Insegnanti";
$langsTeacher = "insegnante";
$langsOfTeacher = "dell'insegnante";
$langsTeachers = "insegnanti";
$langsOfTeachers = "degli insegnanti";
$langStudent = "Studente";
$langOfStudent = "dello Studente";
$langStudents = "Studenti";
$langOfStudents = "degli Studenti";
$langsStudent = "studente";
$langsOfStudent = "dello studente";
$langsStudents = "studenti";
$langsOfStudents = "degi studenti";
$langsOfStudentss = "studenti";
$langsstudent_acc = "studente";
$langGuest = 'Utente Ospite';
$langGuests = 'Utenti Ospiti';
$langFaculty = 'Facoltà - Dipartimento';
$langOfFaculty = 'della Facoltà - del Dipartimento';
$langOfFaculties = "delle Facoltà - dei Dipartimenti";
$langFaculties = "Facoltà - Dipartimenti";
$langsFaculty = "facoltà - dipartimento";
$langsFaculties = "facoltà - dipartimenti";
$langpre = "Laurea";
$langpost = "Post Laurea";
$langother = 'Altro';
$langInfoAbout = "La piattaforma <strong>$siteName</strong>  è un sistema completo di gestione di corsi elettronici. Adotta la filosofia del software a codice sorgente aperto e supporta il servizio di e-learning asincrono senza limitazioni ed impegni. L'accesso al servizio si fa con l'uso di un semplice web browser senza l'esigenza di nozioni tecniche e speciali.";
$langExtrasLeft = '';
$langExtrasRight = '';
$langCourses = "corsi";
$langGroupTutor = "Group Tutor";
$langEditor = "Insegnante di Sostegno";
$langOfEditor = "Tutor Assistant";
$langsEditor = "tutor assistant";
$langsOfEditor = "tutor assistant";
$langsOfGroupTutor = "group tutor";
$langOfCourse = "Course";
$langOfCourses = "Courses";
$langsCourse = "course";
$langsCourses = "courses";
$langsOfCourse = "course";
$langsOfCourses = "courses";
$langsOfFaculty = "category";
$langCourseAdmin = "Admin";
$langOfCourseAdmin = "Admin";
$langCourseAdmins = "Admins";
$langOfCourseAdmins = "Admins";
$langsCourseAdmin = "admin";
$langsOfCourseAdmin = "admin";
$langsCourseAdmins = "admins";
$langsOfCourseAdmins = "admins";
$langCourseAdminTeacher = "Admin - Teacher";
$langOfCourseAdminTeacher = "Admin - Teacher";
$langCourseAdminTeachers = "Admins - Teachers";
$langOfCourseAdminTeachers = "Admins - Teachers";
$langsCourseAdminTeacher = "admin - teacher";
$langsOfCourseAdminTeacher = "admin - teacher";
$langsCourseAdminTeachers = "admins - teachers";
$langsOfCourseAdminTeachers = "admins - teachers";
$langCourseReviewer = "Reviewer";
$langOfCourseReviewer = "Reviewer";
$langsCourseReviewer = "reviewer";
$langsOfCourseReviewer = "reviewer";
$langCTeacher = "INSTRUCTOR";
$langCStudent = "LEARNER";
$langCStudent2 = "STUDENT";
$langAlignment = "Alignment";
$langWidth = "Width";
$langAlignLeft = "Left";
$langAlignCenter = "Center";
$langAlignRight = "Right";
